=========================
django-codenerix-payments
=========================

Codenerix Payments is a module that enables `CODENERIX <https://www.codenerix.com/>`_ to manage payments and let clients to pay online.

.. image:: https://github.com/codenerix/django-codenerix/raw/master/codenerix/static/codenerix/img/codenerix.png
    :target: https://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

********
Features
********

This module support the next providers:

* `Paypal <https://www.paypal.com/>`_
* `Redsys <https://www.redsys.es/en/>`_
* `Yeepay <https://yeepay.com/>`_

****
Demo
****

You can have a look to our demos online:

* `CODENERIX Simple Agenda DEMO <http://demo.codenerix.com>`_.
* `CODENERIX Full ERP DEMO <https://erp.codenerix.com>`_.

You can find some working examples in GITHUB at `django-codenerix-examples <https://github.com/codenerix/django-codenerix-examples>`_ project.

**********
Quickstart
**********

1. Install this package::

    sudo pip3 install django-codenerix-payments

2. Add "codenerix_payments" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_payments',
    ]

3. Since Codenerix Payments is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us?

You can get in touch with us `here <https://codenerix.com/contact/>`_.
